@@ -1,4 +1,5 @@
 import json
+import logging
 import functools
 import traceback
 from sqlalchemy import orm
@@ -30,6 +31,8 @@ def response_factory(status, body):
     }
 
 
+# TODO can remove need for output translators defined in lambda_function files by making this fit the
+# type of the output response(raw_output)
 def success_response_output():
     return 200, "success"
 
@@ -43,10 +46,7 @@ def get_claims_from_event(event):
         token = event['headers']['Authorization'].split()[-1]
         return cognito_validation.get_and_verify_claims(token)
     except Exception as e:
-        # TODO stacktrace
-        # TODO do that by a logger
-        print('Issue getting claims, e is:')
-        print(e)
+        logging.exception('Issue getting claims, e is:' + str(e))
         raise AuthException()
 
 
@@ -75,20 +75,33 @@ class GLH():
             session.commit()
         except InputException as e:
             response_code = 400
-            response_body = "bad input"
+            exception_str = str(e)
+            if not exception_str:
+                response_body = "bad input"
+            else:
+                response_body = exception_str
             session.rollback()
         except AuthException as e:
             response_code = 401
             response_body = "unauthorized"
             session.rollback()
         except Exception as e:
-            print('exception handling http request, e is:')
-            print(e)
-            traceback.print_exception(type(e), e, e.__traceback__)
+            logging.exception('exception handling http request, e is:' + str(e))
             response_code = 500
-            response_body = "service error"
+            exception_str = str(e)
+            if not exception_str:
+                response_body = "service error"
+            else:
+                response_body = exception_str
             session.rollback()
         finally:
             session.close()
 
         return response_factory(response_code, response_body)
+
+
+# thoughts with fresh eyes
+# the main two problems this solves are:
+# 1) allow injecting session, instead of mocking 
+# 2) separate what could potentially be a large method into smaller methods, even though there is no branching
+#     2a) this makes more tests, but the tests are smaller
